web/data/cubicweb.htmlhelpers.js
branchtls-sprint
changeset 1419 7ff24154351d
parent 30 25ef1dddaab8
child 2130 caa5acbecc08
--- a/web/data/cubicweb.htmlhelpers.js	Tue Apr 21 19:20:56 2009 +0200
+++ b/web/data/cubicweb.htmlhelpers.js	Wed Apr 22 16:50:46 2009 +0200
@@ -111,13 +111,13 @@
 }
 
 /* builds an url from an object (used as a dictionnary)
  * Notable difference with MochiKit's queryString: as_url does not
  * *url_quote* each value found in the dictionnary
  *
- * >>> as_url({'rql' : "RQL", 'x': [1, 2], 'itemvid' : "oneline"})
+ * >>> asURL({'rql' : "RQL", 'x': [1, 2], 'itemvid' : "oneline"})
  * rql=RQL&vid=list&itemvid=oneline&x=1&x=2
  */
-function as_url(props) {
+function asURL(props) {
     var chunks = [];
     for(key in props) {
 	var value = props[key];
@@ -111,13 +111,13 @@
 
 /* builds an url from an object (used as a dictionnary)
- * Notable difference with MochiKit's queryString: as_url does not
+ * Notable difference with MochiKit's queryString: asURL does not
  * *url_quote* each value found in the dictionnary
  *